# Audio Convert

A [vsview](https://github.com/Jaded-Encoding-Thaumaturgy/vs-view) plugin for converting audio sample types and resampling audio clips.

## Documentation

Usage and configuration details are available in the [documentation](https://jaded-encoding-thaumaturgy.github.io/vs-view/plugins/second-party/#audio-convert)
